---
title: <span class="badge builder"></span> VizTextDisplayOptions
---
# <span class="badge builder"></span> VizTextDisplayOptions

## Constructor

```python
VizTextDisplayOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.VizTextDisplayOptions
```

### <span class="badge object-method"></span> title_size

Explicit title text size

```python
def title_size(title_size: float) -> typing.Self
```

### <span class="badge object-method"></span> value_size

Explicit value text size

```python
def value_size(value_size: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [VizTextDisplayOptions](./object-VizTextDisplayOptions.md)
